@@ -10,8 +10,6 @@ from .typeahead import typeahead_chains
 from .update import update_chains
 from .view import view_chains
 
-from .related.list import related_list_chains
-
 __all__ = ['generic']
 
 
@@ -45,11 +43,9 @@ Generic = namedtuple(
         'order',
         'typeahead',
         'update',
-        'view',
-
-        # Related
-        'related_list'
-    ])
+        'view'
+    ]
+)
 
 # Create an instance of Generic containing all the generic views
 generic = Generic(
@@ -62,7 +58,4 @@ generic = Generic(
     typeahead=typeahead_chains,
     update=update_chains,
     view=view_chains,
-
-    # Related
-    related_list=related_list_chains
 )
